@@ -3,4 +3,8 @@ class UnknownAnnotationTypeException(Exception):
 
 
 class InvalidTableMetaDataException(Exception):
-    '''exception is raised when metadata for a table is not valid or is missing'''
\ No newline at end of file
+    '''exception is raised when metadata for a table is not valid or is missing'''
+
+
+class InvalidSchemaField(Exception):
+    '''Exception raised if a schema can't be translated to a model'''
\ No newline at end of file
