@@ -7,22 +7,19 @@ import marshmallow as mm
 
 def test_model_creation():
     metadata_dict = {
-                        'synapseflatref':{
+                        'spinecall':{
                             'reference_table':'synapse'
                         }
                     }
     model_dict = make_dataset_models('test', [('synapse', 'synapse'),
-                                              ('flat_segmentation_reference', 'synapseflatref')],
-                                              metadata_dict=metadata_dict,
+                                              ('postsynaptic_compartment', 'spinecall')],
                                               include_contacts=True)
     model = model_dict['synapse']
-    assert(model.__name__ == "TestSynapse")
-    model = model_dict['cellsegment']
-    assert(model.__name__ == "TestCellSegment")
+    assert(model.__name__ == "annov1__test__synapse")
     model = model_dict['contact']
-    assert(model.__name__ == "TestContact")
-    model = model_dict['synapseflatref']
-    assert(model.__name__ == 'TestSynapseflatref')
+    assert(model.__name__ == "annov1__test__contact")
+    model = model_dict['spinecall']
+    assert(model.__name__ == 'annov1__test__spinecall')
     assert(issubclass(model, Base))
 
     # TODO better tests here
@@ -36,6 +33,6 @@ def test_model_failure():
         nest = mm.fields.Nested(NestSchema, many=True)
 
     with pytest.raises(InvalidSchemaField):
-        make_annotation_model_from_schema('test', 'badschema', BadSchema)
+        make_annotation_model_from_schema('testBad',BadSchema)
     with pytest.raises(InvalidSchemaField):
-        make_annotation_model_from_schema('test', 'nestschema', NestSchema)
+        make_annotation_model_from_schema('testNest', NestSchema)
